pub struct VerificationLoop { /* private fields */ }Expand description
Ralph-style verification loop with up to two automatic repairs.
Implementations
Sourceimpl VerificationLoop
impl VerificationLoop
Sourcepub fn new(config: VerificationLoopConfig) -> Self
pub fn new(config: VerificationLoopConfig) -> Self
Create a new verification loop with the provided configuration.
Sourcepub async fn run<Produce, ProduceFuture, Verify, VerifyFuture>(
&self,
produce: Produce,
verify: Verify,
) -> VerificationReport
pub async fn run<Produce, ProduceFuture, Verify, VerifyFuture>( &self, produce: Produce, verify: Verify, ) -> VerificationReport
Run the verification loop over a generated candidate.